@@ -120,6 +120,14 @@ class Group(OperationGroup):
         path="/api/v1/apis/{api_name}/resource-docs/import/by-swagger/",
     )
 
+    # bkapi resource list_resource_versions
+    list_resource_versions = bind_property(
+        Operation,
+        name="list_resource_versions",
+        method="GET",
+        path="/api/v1/apis/{api_name}/resource_versions/",
+    )
+
     # bkapi resource release
     # 发布版本
     release = bind_property(
