@@ -17,7 +17,7 @@ __all__ = [
 HEADER_BK_AUTHORIZATION = "X-Bkapi-Authorization"
 
 
-def get_client_by_request(request, stage="prod", common_args=None, headers={}):
+def get_client_by_request(request, stage="prod", common_args=None, headers=None):
     """根据当前请求返回一个client
     :param request: 一个django request实例
     :param stage: 请求环境，默认为prod
@@ -25,6 +25,8 @@ def get_client_by_request(request, stage="prod", common_args=None, headers={}):
     :param headers: 头部信息
     :returns: 一个初始化好的APIClint对象
     """
+    headers = headers or {}
+
     is_authenticated = request.user.is_authenticated
     if callable(is_authenticated):
         is_authenticated = is_authenticated()
@@ -41,14 +43,14 @@ def get_client_by_request(request, stage="prod", common_args=None, headers={}):
         except Exception:
             pass
     else:
-        raise APIException(u"用户未通过验证")
+        raise APIException("用户未通过验证")
 
     return RequestAPIClient(
         app_code=APP_CODE, app_secret=SECRET_KEY, headers=headers, common_args=common_args, stage=stage
     )
 
 
-def get_client_by_user(user, stage="prod", common_args=None, headers={}):
+def get_client_by_user(user, stage="prod", common_args=None, headers=None):
     """根据user实例返回一个client
     :param user: 用户
     :param stage: 请求环境，默认为prod
@@ -56,6 +58,7 @@ def get_client_by_user(user, stage="prod", common_args=None, headers={}):
     :param headers: 头部信息
     :returns: 一个初始化好的APIClint对象
     """
+    headers = headers or {}
     if hasattr(user, "username"):
         user = user.username
     try:
